module Uncommon = Uncommon
module Poly1305 = Poly1305.It
module type AEAD = Aead.AEAD
include Cipher_block
module Chacha20 = Chacha20
include Cipher_stream
